Hosted webapp and API
======================

All the 3 models can be run on a given judgment text and visualized using our `webapp <https://summarizer-fer6v2lowq-uc.a.run.app/>`_

We provide access to the hosted prediction API of the 3 models upon request.